| Title: | FIDE Chess Players Ratings for 2015 and 2020 |
|---|---|
| Description: | Datasets of the International Chess Federation's player ratings and country information analysed in the book Antony Unwin (2024, ISBN:978-0367674007) "Getting (more out of) Graphics". |
| Authors: | Antony Unwin [aut, cre, cph] |
| Maintainer: | Antony Unwin <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1.0 |
| Built: | 2026-05-24 06:30:21 UTC |
| Source: | https://github.com/cran/ChessGmooG |
Ratings for every chess player, active or inactive, reported by FIDE, the International Chess Federation, in December 2015.
data(Chess2015)data(Chess2015)
A data frame with 227960 observations on the following 7 variables.
ID_NumberID number of player
FedAbbreviation for national federation of player
SexSex of player, M or F
TitTitle, if any: GM, IM, WGM, FM, WIM, CM, WFM, WCM
DEC15Player rating in December 2015
BdayYear of birth
FlagIndicator variable: i (male inactive), wi (female inactive), w (female active)
This dataset and the datasets Chess2020 and ChessCountries are used in Chapter 8, "Comparing chess players across the board".
data(Chess2015, package="ChessGmooG") with(Chess2015, summary(DEC15))data(Chess2015, package="ChessGmooG") with(Chess2015, summary(DEC15))
Ratings for every chess player, active or inactive, reported by FIDE, the International Chess Federation, in December 2020.
data(Chess2020)data(Chess2020)
A data frame with 362502 observations on the following 7 variables.
ID_NumberID number of player
FedAbbreviation for national federation of player
SexSex of player, M or F
TitTitle, if any: GM, IM, WGM, FM, WIM, CM, WFM, WCM
DEC20Player rating in December 2020
BdayYear of birth
FlagIndicator variable: i (male inactive), wi (female inactive), w (female active)
This dataset and the datasets Chess2015 and ChessCountries are used in Chapter 8, "Comparing chess players across the board".
data(Chess2020, package="ChessGmooG") with(Chess2020, summary(DEC20))data(Chess2020, package="ChessGmooG") with(Chess2020, summary(DEC20))
Populations of countries with chess players rated by FIDE and grouping of the countries into regions.
data(ChessCountries)data(ChessCountries)
A data frame with 188 observations on the following 8 variables.
Fed1Abbreviation for country
CountryName of country
RegionOne of seven regional groupings of countries by the World Bank
fTNumber of country's active chess players in December 2020
PopulationPopulation according to the World Bank
GMNumber of country's active grandmasters in December 2020
C1Factor variable of names of countries
C1aFactor variable of 30 countries with most players, with remaining countries grouped as "Other"
This dataset and the datasets Chess2015 and Chess2020 are used in Chapter 8, "Comparing chess players across the board".
data(ChessCountries, package="ChessGmooG") with(ChessCountries, table(Region, useNA="always"))data(ChessCountries, package="ChessGmooG") with(ChessCountries, table(Region, useNA="always"))
The two datasets of chess ratings from December 2020 and December 2015 are each bigger than 1Mb, so they are provided in this package.
Most of the datasets analysed in the book are available in GmooG and other R packages.
Antony Unwin [email protected]